# Generated by Django 5.2.5 on 2025-08-19 08:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymenttransaction',
            name='gateway',
            field=models.CharField(choices=[('payme', 'Payme'), ('click', 'Click'), ('atmos', 'Atmos')], max_length=10),
        ),
    ]
